==> moe-0.6.tar.bz2: moe-0.6/screen.h <==
/*  GNU Moe - My Own Editor
    Copyright (C) 2005, 2006 Antonio Diaz Diaz.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/

namespace Screen {

enum Keys { key_up, key_down, key_left, key_right, key_npage, key_ppage,
            key_home, key_end, key_invalid };

bool init() throw();

//void beep() throw();


// Wait for a keystroke.
// The clock only blinks when waiting here for a keystroke.
// The screen is also only refreshed here (and in clock_handler).
// This function is the real "main loop" of the program.
//
int wait_kbhit( const int new_clock_limit = -1, const bool get_key = true ) throw();
int kbhit() throw();

void clock_handler( const int sig ) throw();		// updates the clock


// 'history.back()' contains the default result (may be empty), and
// stores the result (if any).
// Returns the size of the result string, 0 if none, -1 if aborted.
//
int get_string( const std::string & prompt,
                std::vector< std::string > & history,
                const bool allow_copy = false, const bool usetab = false ) throw();


int height() throw();
int width() throw();

void move_to( const Point & cursor ) throw();
void save_cursor( Point & cursor ) throw();
void save_lines_and_cursor( const int line, const int lines ) throw();
void restore_lines_and_cursor() throw();

void out_buffer_line( const Buffer & buffer, Point c, const int line ) throw();
bool out_line( const std::string & s, const int line, const bool shift = false ) throw();
//void repaint( const Buffer * bufp = 0 ) throw();
int show_message( const std::string & s, const bool get_key = false,
                  const bool take_cursor = false ) throw();
void show_status_lines() throw();

Keys convert_key( const int key ) throw();
int user_loop( const std::string & version_msg ) throw();

} // end namespace Screen

==> moe-0.7.tar.bz2: moe-0.7/screen.h <==
/*  GNU Moe - My Own Editor
    Copyright (C) 2005, 2006 Antonio Diaz Diaz.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/

namespace Screen {

enum Keys { key_up, key_down, key_left, key_right, key_npage, key_ppage,
            key_home, key_end, key_invalid };

bool init() throw();

//void beep() throw();

void clock_handler( const int sig ) throw();		// Updates the clock.

int kbhit() throw();			// Returns -1 if no key is available.

// Wait for a keystroke. Returns -1 if no key is available.
// The clock only blinks when waiting here for a keystroke.
// The screen is also only refreshed here (and in clock_handler).
// This function is the real "main loop" of the program.
//
int wait_kbhit( const int new_clock_limit = -1, const bool get_key = true,
                const bool force_refresh = false ) throw();


// 'history.back()' contains the default result (may be empty), and
// stores the result (if any).
// Returns the size of the result string, 0 if none, -1 if aborted.
//
int get_string( const std::string & prompt,
                std::vector< std::string > & history,
                const int abort_key = 3,
                const bool allow_copy = false, const bool usetab = false ) throw();


int height() throw();
int width() throw();

void move_to( const Point & cursor ) throw();
void save_cursor( Point & cursor ) throw();
void save_lines_and_cursor( const int line, const int lines ) throw();
void restore_lines_and_cursor() throw();

void out_buffer_line( const Buffer & buffer, Point c, const int line ) throw();
bool out_line( const std::string & s, const int line, const bool shift = false,
               const char mode = 0 ) throw();
int show_message( const std::string & s, const bool get_key = false,
                  const bool take_cursor = false ) throw();

Keys convert_key( const int key ) throw();
int user_loop( const std::string & version_msg ) throw();

} // end namespace Screen
